@@ -6,17 +6,20 @@ import sys
 import logging
 import click
 
-# add serum package to path
+# add mldock package to path
 sys.path.insert(1, ".")
 
+from mldock.__version__ import __version__
 from mldock.__init__ import MLDOCK_LOGO
 from mldock.command.initialize import init
 from mldock.command.local import local
-from mldock.command.push import push
+from mldock.command.cloud import cloud
 from mldock.log import configure_logger
 
 click.disable_unicode_literals_warning = True
 
+CLI_VERSION = 'cli {}'.format(__version__)
+
 @click.group()
 @click.option(u"-v", u"--verbose", count=True, help=u"Turn on debug logging")
 @click.option(u"-t", u"--docker-tag", default=u"latest", help=u"Specify tag for Docker image")
@@ -28,12 +31,13 @@ def cli(ctx, verbose, docker_tag):
     _FILE_DIR_PATH = os.path.dirname(os.path.realpath(__file__))
     logger=configure_logger('mldock', verbose=verbose)
     logger.info(MLDOCK_LOGO)
+    logger.info('Version: ' + CLI_VERSION)
     ctx.obj = {'verbose': verbose, 'docker_tag': docker_tag, 'helper_library_path':_FILE_DIR_PATH}
 
 def add_commands(cli):
     cli.add_command(init)
     cli.add_command(local)
-    cli.add_command(push)
+    cli.add_command(cloud)
 
 add_commands(cli)
 
