@@ -13,6 +13,8 @@ logger=logging.getLogger('mldock')
 
 
 def generic_init(dir, helper_library_path, sagify_config, new, testing_framework, service):
+
+    logger.info("starting generic init")
     src_directory = os.path.join(
         dir,
         sagify_config.get("sagify_module_dir", "src")
@@ -22,54 +24,19 @@ def generic_init(dir, helper_library_path, sagify_config, new, testing_framework
         'service'
     )
 
-    template_dir = 'templates'
-
-    template_dir = os.path.join(
-        helper_library_path,
-        'templates',
-        sagify_config['platform']
-    )
-
-    sagify_module_path = os.path.join(
-        src_directory,
-        'container'
-    )
-
-    test_path = os.path.join(sagify_module_path, 'local_test', 'test_dir')
-
-    # generic copy
-    if new:
-        logger.info("Creating new workspace")
-        _copy_boilerplate_to_dst(os.path.join(template_dir,'src/'), src_directory)
-    if testing_framework == 'pytest':
-        logger.info("Adding pytest container tests")
-        _copy_boilerplate_to_dst(os.path.join(template_dir,'tests/'), 'tests/')
-        logger.info("renaming test file")
-
-        _rename_file(
-            base_path='tests/container_health',
-            current_filename='_template_test_container.py',
-            new_filename='test_{ASSET_DIR}.py'.format(ASSET_DIR=dir)
-        )
-    if service == 'compose':
-        logger.info("Adding service")
-        _copy_boilerplate_to_dst(os.path.join(template_dir,'service/'), service_directory)
-
-def sagemaker_init(dir, helper_library_path, sagify_config, new, testing_framework):
-
-    src_directory = os.path.join(
-        dir,
-        sagify_config.get("sagify_module_dir", "src")
-    )
-
+    logger.info("getting template")
     template_dir = sagify_config.get("template_dir", None)
 
     if template_dir is None:
         template_dir = os.path.join(
             helper_library_path,
-            template_dir,
+            "templates",
             sagify_config['platform']
         )
+        logger.info("--- no template dir provided, using = (Default) {}".format(sagify_config['platform']))
+
+    logger.info("Template directory = {}".format(template_dir))
+
 
     sagify_module_path = os.path.join(
         src_directory,
@@ -92,6 +59,61 @@ def sagemaker_init(dir, helper_library_path, sagify_config, new, testing_framewo
             current_filename='_template_test_container.py',
             new_filename='test_{ASSET_DIR}.py'.format(ASSET_DIR=dir)
         )
+    if service is not None:
+        logger.info("Adding {} service".format(service))
+        _copy_boilerplate_to_dst(os.path.join(template_dir,'service',service), service_directory)
+
+def sagemaker_init(dir, helper_library_path, sagify_config, new, testing_framework, service):
+
+    logger.info("starting sagemaker init")
+    src_directory = os.path.join(
+        dir,
+        sagify_config.get("sagify_module_dir", "src")
+    )
+
+    service_directory = os.path.join(
+        dir,
+        'service'
+    )
+
+    logger.info("getting template")
+    template_dir = sagify_config.get("template_dir", None)
+
+    if template_dir is None:
+        template_dir = os.path.join(
+            helper_library_path,
+            "templates",
+            sagify_config['platform']
+        )
+        logger.info("--- no template dir provided, using = (Default) {}".format(sagify_config['platform']))
+
+    logger.info("Template directory = {}".format(template_dir))
+
+    sagify_module_path = os.path.join(
+        src_directory,
+        'container'
+    )
+
+    test_path = os.path.join(sagify_module_path, 'local_test', 'test_dir')
+
+    # generic copy
+    if new:
+        logger.info("Creating new workspace")
+        _copy_boilerplate_to_dst(os.path.join(template_dir,'src/'), src_directory)
+    if testing_framework == 'pytest':
+        logger.info("Adding pytest container tests")
+        _copy_boilerplate_to_dst(os.path.join(template_dir,'tests/'), 'tests/')
+        logger.info("renaming test file")
+
+        _rename_file(
+            base_path='tests/container_health',
+            current_filename='_template_test_container.py',
+            new_filename='test_{ASSET_DIR}.py'.format(ASSET_DIR=dir)
+        )
+
+    if service is not None:
+        logger.info("Adding {} service".format(service))
+        _copy_boilerplate_to_dst(os.path.join(template_dir,'service',service), service_directory)
 
     # sagemaker
     config_path = os.path.join(test_path, 'input/config')
