@@ -31,7 +31,7 @@ def init(obj, dir, new, testing_framework, service):
     try:
         logger.info("Getting Sagify config")
         sagify_manager = SagifyConfigManager(
-            filepath=os.path.join(dir, ".sagify.json")
+            filepath=os.path.join(dir, ".mldock.json")
         )
         if new:
             sagify_manager.setup_config()
@@ -64,9 +64,10 @@ def init(obj, dir, new, testing_framework, service):
                 helper_library_path=helper_library_path,
                 sagify_config=sagify_config,
                 new=new,
-                testing_framework=testing_framework
+                testing_framework=testing_framework,
+                service=service
             )
-        elif platform == "bare":
+        elif platform == "generic":
             generic_init(
                 dir=dir,
                 helper_library_path=helper_library_path,
