@@ -39,7 +39,7 @@ def build(obj, dir, no_cache):
     helper_library_path = obj['helper_library_path']
     try:
         sagify_manager = SagifyConfigManager(
-            filepath=os.path.join(dir, ".sagify.json")
+            filepath=os.path.join(dir, ".mldock.json")
         )
         # get sagify_module_path name
         sagify_config = sagify_manager.get_config()
@@ -128,7 +128,7 @@ def train(obj, dir, tag):
     Command to train ML model(s) locally
     """
     sagify_manager = SagifyConfigManager(
-        filepath=os.path.join(dir, ".sagify.json")
+        filepath=os.path.join(dir, ".mldock.json")
     )
     # get sagify_module_path name
     sagify_config = sagify_manager.get_config()
@@ -179,7 +179,7 @@ def deploy(obj, dir, tag, host):
     """
     helper_library_path=obj['helper_library_path']
     sagify_manager = SagifyConfigManager(
-        filepath=os.path.join(dir, ".sagify.json")
+        filepath=os.path.join(dir, ".mldock.json")
     )
     # get sagify_module_path name
     sagify_config = sagify_manager.get_config()
