@@ -152,7 +152,7 @@ class SagifyConfigManager(BaseConfigManager):
         """
         platform_name = click.prompt(
             text="Set your platform name:",
-            default='bare'
+            default='generic'
         )
 
         self.config.update({
